@@ -101,7 +101,7 @@ namespace libtorrent
 		char const* torrent_name() const;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string name;
+		std::string TORRENT_DEPRECATED_MEMBER name;
 #endif
 
 	protected:
@@ -149,7 +149,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// The tracker URL
-		std::string url;
+		std::string TORRENT_DEPRECATED_MEMBER url;
 #endif
 	private:
 		int m_url_idx;
@@ -195,11 +195,14 @@ namespace libtorrent
 #define TORRENT_DEFINE_ALERT_PRIO(name, seq) \
 	TORRENT_DEFINE_ALERT_IMPL(name, seq, 1)
 
+#ifndef TORRENT_NO_DEPRECATE
 	// The ``torrent_added_alert`` is posted once every time a torrent is successfully
 	// added. It doesn't contain any members of its own, but inherits the torrent handle
 	// from its base class.
 	// It's posted when the ``status_notification`` bit is set in the alert_mask.
-	struct TORRENT_EXPORT torrent_added_alert TORRENT_FINAL : torrent_alert
+	// deprecated in 1.1.3
+	// use add_torrent_alert instead
+	struct TORRENT_DEPRECATED_EXPORT torrent_added_alert TORRENT_FINAL : torrent_alert
 	{
 		// internal
 		torrent_added_alert(aux::stack_allocator& alloc, torrent_handle const& h);
@@ -208,6 +211,7 @@ namespace libtorrent
 		static const int static_category = alert::status_notification;
 		virtual std::string message() const TORRENT_OVERRIDE;
 	};
+#endif
 
 	// The ``torrent_removed_alert`` is posted whenever a torrent is removed. Since
 	// the torrent handle in its base class will always be invalid (since the torrent
@@ -290,7 +294,7 @@ namespace libtorrent
 		static const int static_category = alert::storage_notification;
 		virtual std::string message() const TORRENT_OVERRIDE;
 #ifndef TORRENT_NO_DEPRECATE
-		std::string name;
+		std::string TORRENT_DEPRECATED_MEMBER name;
 #endif
 
 		char const* new_name() const;
@@ -469,7 +473,7 @@ namespace libtorrent
 		int status_code;
 		error_code error;
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 
 		// the message associated with this error
@@ -497,7 +501,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// contains the warning message from the tracker.
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 
 		// the message associated with this warning
@@ -549,7 +553,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// contains a message describing the error.
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 
 		// the error itself. This may indicate that the tracker sent an error
@@ -704,7 +708,7 @@ namespace libtorrent
 		error_code error;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 	};
 
@@ -752,7 +756,7 @@ namespace libtorrent
 		close_reason_t reason;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 	};
 
@@ -886,7 +890,7 @@ namespace libtorrent
 		virtual std::string message() const TORRENT_OVERRIDE;
 
 #ifndef TORRENT_NO_DEPRECATE
-		char const* peer_speedmsg;
+		char const* TORRENT_DEPRECATED_MEMBER peer_speedmsg;
 #endif
 		int block_index;
 		int piece_index;
@@ -925,7 +929,7 @@ namespace libtorrent
 		virtual std::string message() const TORRENT_OVERRIDE;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string path;
+		std::string TORRENT_DEPRECATED_MEMBER path;
 #endif
 
 		// the path the torrent was moved to
@@ -955,7 +959,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// If the error happened for a specific file, ``file`` is its path.
-		std::string file;
+		std::string TORRENT_DEPRECATED_MEMBER file;
 #endif
 
 		// If the error happened for a specific file, this returns its path.
@@ -1013,7 +1017,7 @@ namespace libtorrent
 		sha1_hash info_hash;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 	};
 
@@ -1053,7 +1057,7 @@ namespace libtorrent
 		error_code error;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 	};
 
@@ -1113,10 +1117,10 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// the HTTP seed that failed
-		std::string url;
+		std::string TORRENT_DEPRECATED_MEMBER url;
 
 		// the error message, potentially from the server
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 
 		// the error the web seed encountered. If this is not set, the server
@@ -1155,7 +1159,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// the path to the file that was accessed when the error occurred.
-		std::string file;
+		std::string TORRENT_DEPRECATED_MEMBER file;
 #endif
 
 		// the error code describing the error.
@@ -1166,7 +1170,7 @@ namespace libtorrent
 		char const* filename() const;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 	private:
 		int m_file_idx;
@@ -1326,7 +1330,7 @@ namespace libtorrent
 	// was opened for listening.
 	struct TORRENT_EXPORT listen_succeeded_alert TORRENT_FINAL : alert
 	{
-		enum socket_type_t { tcp, tcp_ssl, udp, utp_ssl };
+		enum socket_type_t { tcp, tcp_ssl, udp, i2p, socks5, utp_ssl };
 
 		// internal
 		listen_succeeded_alert(aux::stack_allocator& alloc, tcp::endpoint const& ep
@@ -1373,7 +1377,7 @@ namespace libtorrent
 		// tells you what failed.
 		error_code error;
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 	};
 
@@ -1432,7 +1436,7 @@ namespace libtorrent
 		int map_type;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 
 		// the message associated with this log line
@@ -1470,7 +1474,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// If the error happened to a specific file, ``file`` is the path to it.
-		std::string file;
+		std::string TORRENT_DEPRECATED_MEMBER file;
 #endif
 
 		// If the error happened to a specific file, this returns the path to it.
@@ -1481,7 +1485,7 @@ namespace libtorrent
 		char const* operation;
 
 #ifndef TORRENT_NO_DEPRECATE
-		std::string msg;
+		std::string TORRENT_DEPRECATED_MEMBER msg;
 #endif
 	private:
 		int m_path_idx;
@@ -1559,6 +1563,8 @@ namespace libtorrent
 	// This alert is posted approximately once every second, and it contains
 	// byte counters of most statistics that's tracked for torrents. Each active
 	// torrent posts these alerts regularly.
+	// This alert has been superceded by calling ``post_torrent_updates()``
+	// regularly on the session object. This alert will be removed
 	struct TORRENT_EXPORT stats_alert TORRENT_FINAL : torrent_alert
 	{
 		// internal
@@ -1578,16 +1584,16 @@ namespace libtorrent
 			download_protocol,
 			upload_ip_protocol,
 #ifndef TORRENT_NO_DEPRECATE
-			upload_dht_protocol,
-			upload_tracker_protocol,
+			upload_dht_protocol TORRENT_DEPRECATED_ENUM,
+			upload_tracker_protocol TORRENT_DEPRECATED_ENUM,
 #else
 			deprecated1,
 			deprecated2,
 #endif
 			download_ip_protocol,
 #ifndef TORRENT_NO_DEPRECATE
-			download_dht_protocol,
-			download_tracker_protocol,
+			download_dht_protocol TORRENT_DEPRECATED_ENUM,
+			download_tracker_protocol TORRENT_DEPRECATED_ENUM,
 #else
 			deprecated3,
 			deprecated4,
@@ -1680,7 +1686,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// The tracker ID returned by the tracker
-		std::string trackerid;
+		std::string TORRENT_DEPRECATED_MEMBER trackerid;
 #endif
 
 		// The tracker ID returned by the tracker
@@ -1767,7 +1773,7 @@ namespace libtorrent
 
 #ifndef TORRENT_NO_DEPRECATE
 		// the filename (or object) the error occurred on.
-		std::string error_file;
+		std::string TORRENT_DEPRECATED_MEMBER error_file;
 #endif
 
 		// the filename (or object) the error occurred on.
@@ -1799,8 +1805,8 @@ namespace libtorrent
 	// an incoming connection, through any mean. The most straight-forward ways
 	// of accepting incoming connections are through the TCP listen socket and
 	// the UDP listen socket for uTP sockets. However, connections may also be
-	// accepted offer a Socks5 or i2p listen socket, or via a torrent specific
-	// listen socket for SSL torrents.
+	// accepted through a Socks5 or i2p listen socket, or via an SSL listen
+	// socket.
 	struct TORRENT_EXPORT incoming_connection_alert TORRENT_FINAL : alert
 	{
 		// internal
@@ -1878,7 +1884,8 @@ namespace libtorrent
 		std::vector<torrent_status> status;
 	};
 
-	struct TORRENT_EXPORT mmap_cache_alert TORRENT_FINAL : alert
+#ifndef TORRENT_NO_DEPRECATE
+	struct TORRENT_DEPRECATED TORRENT_EXPORT mmap_cache_alert TORRENT_FINAL : alert
 	{
 		mmap_cache_alert(aux::stack_allocator& alloc
 			, error_code const& ec);
@@ -1889,6 +1896,7 @@ namespace libtorrent
 
 		error_code error;
 	};
+#endif
 
 	// The session_stats_alert is posted when the user requests session statistics by
 	// calling post_session_stats() on the session object. Its category is
@@ -2403,7 +2411,12 @@ namespace libtorrent
 		sha1_hash info_hash;
 
 		int num_peers() const;
-		void peers(std::vector<tcp::endpoint>& peers) const;
+
+#ifndef TORRENT_NO_DEPRECATE
+		TORRENT_DEPRECATED
+		void peers(std::vector<tcp::endpoint>& v) const;
+#endif
+		std::vector<tcp::endpoint> peers() const;
 
 	private:
 		aux::stack_allocator& m_alloc;
@@ -2441,8 +2454,10 @@ namespace libtorrent
 	// this is posted when one or more blocks are picked by the piece picker,
 	// assuming the verbose piece picker logging is enabled (see
 	// picker_log_notification).
-	struct TORRENT_EXPORT picker_log_alert : peer_alert
+	struct TORRENT_EXPORT picker_log_alert TORRENT_FINAL : peer_alert
 	{
+		TORRENT_DEFINE_ALERT(picker_log_alert, 89)
+
 #ifndef TORRENT_DISABLE_LOGGING
 
 		// internal
@@ -2450,8 +2465,6 @@ namespace libtorrent
 			, tcp::endpoint const& ep, peer_id const& peer_id, boost::uint32_t flags
 			, piece_block const* blocks, int num_blocks);
 
-		TORRENT_DEFINE_ALERT(picker_log_alert, 89)
-
 		static const int static_category = alert::picker_log_notification;
 		virtual std::string message() const TORRENT_OVERRIDE;
 
